@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: xmlhtml
-version: 0.2.0.2
-id: xmlhtml-0.2.0.2-787261716cacb64ecb3a4e86590dd0e5
+version: 0.2.1
+id: xmlhtml-0.2.1-024fbdca2ca705169920f98d3cb47c28
 
 license: BSD3
 copyright:
@@ -34,33 +34,32 @@ author: Chris Smith <cdsmith@gmail.com>
 pkgpath: textproc/hs-xmlhtml
 exposed: True
 exposed-modules: Text.XmlHtml Text.XmlHtml.Cursor
-                 Text.Blaze.Renderer.XmlHtml
+                 Text.XmlHtml.HTML.Meta Text.Blaze.Renderer.XmlHtml
 hidden-modules: Text.XmlHtml.Common Text.XmlHtml.TextParser
                 Text.XmlHtml.XML.Parse Text.XmlHtml.XML.Render
-                Text.XmlHtml.HTML.Meta Text.XmlHtml.HTML.Parse
-                Text.XmlHtml.HTML.Render
+                Text.XmlHtml.HTML.Parse Text.XmlHtml.HTML.Render
 trusted: False
-import-dirs: /usr/local/lib/ghc/xmlhtml-0.2.0.2
-library-dirs: /usr/local/lib/ghc/xmlhtml-0.2.0.2
-hs-libraries: HSxmlhtml-0.2.0.2
+import-dirs: /usr/local/lib/ghc/xmlhtml-0.2.1
+library-dirs: /usr/local/lib/ghc/xmlhtml-0.2.1
+hs-libraries: HSxmlhtml-0.2.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         blaze-builder-0.2.1.4-7e5834be78fd9cd5b05f4a14f4001d18
-         blaze-html-0.5.0.0-09f6e27ccba2168f1557f9c82181429a
-         blaze-markup-0.5.1.0-6ef6c7afdc8718d3fd722a1fcd86e32b
-         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
-         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
-         parsec-3.1.3-07e54fceec3486ec01b4c366cf3d07fd
-         text-0.11.2.3-0a507fb72e97feed1b44644051bc0e5f
-         unordered-containers-0.1.4.6-a7207f78d453daba3716dfc838a574ed
+depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
+         blaze-builder-0.3.1.1-ac49b512143342e2370aead8ef93c70b
+         blaze-html-0.6.1.1-d9a2e0519a92c20d0751dbc779791ce7
+         blaze-markup-0.5.1.5-2469a9388e0fb2943fc206e9c09e2bea
+         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
+         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+         parsec-3.1.3-b22b2727b76201c9de9a61961208ca5b
+         text-0.11.3.1-bda2125c8335eaa4aca16bb46c88465a
+         unordered-containers-0.2.3.0-5bf92a1c1b90f6e2e5a5dbbd8a6ab013
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-xmlhtml-0.2.0.2/html/xmlhtml.haddock
-haddock-html: /usr/local/share/doc/hs-xmlhtml-0.2.0.2/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-xmlhtml-0.2.1/html/xmlhtml.haddock
+haddock-html: /usr/local/share/doc/hs-xmlhtml-0.2.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
